/*
 * Created on Jan 28, 2004
 *
 * Copyright TimeSys Corp. 2003
 * All Rights Reserved
 */
package org.eclipse.cdt.toolchain;

/**
 * The toolchain class provides some methods for uniform display of all 
 * toolchains.  All the "real" work of toolchain is done by the 
 * IToolchainCapabilities returned from this class.
 * @author jeremiah.lott
 */
public interface IToolchain {

	/**
	 * Returns an id for the toolchain.  The id must be unique within the
	 * toolchain factory for this toolchain.  Therefore a factory id +
	 * a toolchain id will uniquely identify a toolchain.
	 */
	String getID();
	
	/**
	 * Should return a name for this toolchain that can be displayed to the 
	 * user.  The preference for any UI-element is to show the short name, and
	 * only display the long name if the short name conflicts with another
	 * toolchain.
	 */
	String getShortName();

	/**
	 * Should return a name for this toolchain that can be displayed to the 
	 * user.  The long name will be shown when the short name is non-unqiue 
	 * (i.e. two plugins are returned with the same short name).  Usually the
	 * long name will append a vendor name and/or version number to make it more
	 * unique.
	 */
	String getLongName();
	
	/**
	 * Returns the capability of the given type, or null if the toolchain 
	 * does not support that capability.
	 */
	IToolchainCapability getCapability(String type);
	
	/**
	 * Returns a list of all the capabilities that this toolchain supports.
	 */
	IToolchainCapability[] getCapabilities();
}
